import {
  select,
  csv,
  scaleLinear,
  extent,
  axisLeft,
  axisBottom
} from 'd3';

import { dropdownMenu } from './dropdownMenu';
import { scatterPlot } from './scatterPlot';


const svg = select('svg');

const width = +svg.attr('width');
const height = +svg.attr('height');

let data;
let xColumn;

const onXColumnClicked = column => {
  xColumn = column;
  render();   	  
};

const render = () => {
  select('#menus')
    .call(dropdownMenu, {
      options: data.columns,
      onOptionClicked: onXColumnClicked
  });
  
  svg.call(scatterPlot, {
    xValue: d => d[xColumn],
    xAxisLabel: xColumn,
  	yValue: d => d.Happiness_Score,
    circleRadius: 10,
  	yAxisLabel: 'Happiness Score',
  	margin: { top: 60, right: 40, bottom: 88, left: 150 },
  	width,
  	height,
    data
  });
};

csv('https://vizhub.com/NTCHANG1289/datasets/2017_world-happiness-report.csv')
  .then(loadedData => {
    data = loadedData;
    data.forEach(d => {
      d.Happiness_Rank = +d.Happiness_Rank;
      d.Happiness_Score = +d.Happiness_Score;
      d.Economy_GDP_per_Capita = +d.Economy_GDP_per_Capita;
      d.Family = +d.Family;
      d.Health_Life_Expectancy = +d.Health_Life_Expectancy;
      d.Freedom = +d.Freedom;
      d.Generosity = +d.Generosity;
      d.Trust_Government_Corruption = +d.Trust_Government_Corruption;
      d.Dystopia_Residual = +d.Dystopia_Residual;
    });
    //xColumn = data.columns[7];
    render();
  });